Generates pseudo-random vectors that follow an arbitrary von Mises-Fisher distribution on a sphere. This method is fast and efficient when generating a large number of pseudo-random vectors. Functions to generate random variates and compute density for the distribution of an inner product between von Mises-Fisher random vector and its mean direction are also provided. Details are in Kang and Oh (2024) tools:::Rd_expr_doi("10.1007/s11222-024-10419-3").
Maintainer: Seungwoo Kang kangsw0401@snu.ac.kr (ORCID)
Authors:
Hee-Seok Oh heeseok@stats.snu.ac.kr
Useful links: